OpenDiscovery
========================

Introduction
------------

Open Discovery is a suite of programs that use Open Source or freely
available tools to dock a library of chemical compounds against a
receptor protein. In a paper in the Journal of Chemical Education, we
outline the usefulness of having an uncomplicated, free-to-use protocol
to accomplish a task that has been the subject of academic and
commercial interest for decades [1]. We also highlight the gaps in open
source tools around preparing protein - ligand complexes for molecular
simulation, an area we expect to develop in the future.

Requirements
------------

-  Open Babel (install from http://openbabel.org/ - version developed
   with: 2.3.1). Open Babel is used for file conversions.

Installation Instructions
-------------------------

Instructions can be found at the following locations:

-  `MacOSX <http://opendiscovery.co.uk/installing-od-osx.html>`_
-  `Ubuntu <http://opendiscovery.co.uk/installing-od-ubuntu.html>`_

References
----------

[1]: `Price, G. W. et al., A. Use of Freely Available and Open Source
Tools for In Silico Screening in Chemical Biology. J. Chem. Educ.
(2014). <http://pubs.acs.org/doi/full/10.1021/ed400302u>`__

Contact
-------

If you wish to get in contact, please email `Gareth
Price <gareth.price@warwick.ac.uk>`__, or file an
`issue <https://github.com/iamgp/OpenDiscovery/issues>`__.